@@ -1,12 +1,18 @@
 import asyncio
 import os
 import threading
+import sys
 from autobahn.asyncio.wamp import ApplicationSession
 from autobahn.wamp import auth
 from autobahn.asyncio.wamp import ApplicationSession
 from autobahn.wamp import auth
 from autobahn.asyncio.wamp import ApplicationRunner
 
+if sys.version_info[:2] >= (3, 7):
+    from asyncio import get_running_loop
+else:
+    from asyncio import _get_running_loop as get_running_loop
+
 DATAPODS_WS_URI = "wss://cbw.datapods.io/ws-ua-usr";
 STUDIO_WS_URI = "wss://cbw.record-evolution.com/ws-ua-usr";
 LOCALHOST_WS_URI = "ws://crossbar_node1/ws-ua-usr";
@@ -51,7 +57,7 @@ class _Component(ApplicationSession):
         self.disconnect()
 
     def onDisconnect(self):
-        loop = asyncio.get_running_loop()
+        loop = get_running_loop()
 
         loop.stop()
         loop.close()
